#outermost[data-v-514d8cf1]{width:100vw;height:100vh;position:relative;background-color:var(--v224b9e78)}#topButtonBarFlex[data-v-514d8cf1]{height:calc(2rem + 2px);position:relative;gap:1rem;padding:.5rem;border-bottom:1px solid var(--v40c70fba)}#controlSpace{&[data-v-514d8cf1]{height:calc(100% - 2rem - 3px);position:relative;overflow:hidden}>.n-layout[data-v-514d8cf1]{max-height:100%}}
