import{N as r}from"./Card-DZFbz07B.js";import{d as s,c as n,bm as i,bn as t,bo as d,a as o,bw as p,o as l}from"./index-bF5zRBEa.js";import"./Close-ChnBNDFL.js";const m={style:{display:"grid",gap:"1rem",padding:"1rem",position:"relative","overflow-x":"hidden"}},a="https://github.com/op200/",h=s({__name:"About",setup(c){return(u,e)=>(l(),n("div",m,[i(d(r),{title:"Windows Font Manager WebUI"},{"header-extra":t(()=>[o("a",{href:a},p(a))]),default:t(()=>[e[0]||(e[0]=o("div",null," 介绍 ",-1))]),_:1})]))}});export{h as default};
